@@ -109,6 +109,7 @@ public:
 		action_group->add(
 				Gtk::Action::create(
 					"video-player/skip-backwards-very-short", 
+					Gtk::Stock::MEDIA_REWIND,
 					_("Very Short"), 
 					_("Very short skip backwards")),
 					sigc::bind( sigc::mem_fun(*this, &VideoPlayerManagement::on_skip_backwards), VERY_SHORT));
@@ -116,6 +117,7 @@ public:
 		action_group->add(
 				Gtk::Action::create(
 					"video-player/skip-backwards-short", 
+					Gtk::Stock::MEDIA_REWIND,
 					_("Short"), 
 					_("Short skip backwards")),
 					sigc::bind( sigc::mem_fun(*this, &VideoPlayerManagement::on_skip_backwards), SHORT));
@@ -123,6 +125,7 @@ public:
 		action_group->add(
 				Gtk::Action::create(
 					"video-player/skip-backwards-medium", 
+					Gtk::Stock::MEDIA_REWIND,
 					_("Medium"), 
 					_("Medium skip backwards")),
 					sigc::bind( sigc::mem_fun(*this, &VideoPlayerManagement::on_skip_backwards), MEDIUM));
@@ -130,6 +133,7 @@ public:
 		action_group->add(
 				Gtk::Action::create(
 					"video-player/skip-backwards-long", 
+					Gtk::Stock::MEDIA_REWIND,
 					_("Long"), 
 					_("Long skip backwards")),
 					sigc::bind( sigc::mem_fun(*this, &VideoPlayerManagement::on_skip_backwards), LONG));
@@ -144,6 +148,7 @@ public:
 		action_group->add(
 				Gtk::Action::create(
 					"video-player/skip-forward-very-short", 
+					Gtk::Stock::MEDIA_FORWARD,
 					_("Very Short"), 
 					_("Very short skip forward")), 
 					sigc::bind( sigc::mem_fun(*this, &VideoPlayerManagement::on_skip_forward), VERY_SHORT));
@@ -151,6 +156,7 @@ public:
 		action_group->add(
 				Gtk::Action::create(
 					"video-player/skip-forward-short", 
+					Gtk::Stock::MEDIA_FORWARD,
 					_("Short"), 
 					_("Short skip forward")), 
 					sigc::bind( sigc::mem_fun(*this, &VideoPlayerManagement::on_skip_forward), SHORT));
@@ -158,6 +164,7 @@ public:
 		action_group->add(
 				Gtk::Action::create(
 					"video-player/skip-forward-medium", 
+					Gtk::Stock::MEDIA_FORWARD,
 					_("Medium"), 
 					_("Medium skip forward")), 
 					sigc::bind( sigc::mem_fun(*this, &VideoPlayerManagement::on_skip_forward), MEDIUM));
@@ -165,6 +172,7 @@ public:
 		action_group->add(
 				Gtk::Action::create(
 					"video-player/skip-forward-long", 
+					Gtk::Stock::MEDIA_FORWARD,
 					_("Long"), 
 					_("Long skip forward")), 
 					sigc::bind( sigc::mem_fun(*this, &VideoPlayerManagement::on_skip_forward), LONG));
@@ -280,6 +288,12 @@ public:
 					_("Show or hide the video player in the current window"), video_player_display_state),
 					sigc::mem_fun(*this, &VideoPlayerManagement::on_video_player_display_toggled));
 
+		action_group->add(
+				Gtk::Action::create(
+					"menu-audio-track",
+					_("Audio Track"),
+					_("Choice of an audio track")));
+
 		// ui
 		Glib::RefPtr<Gtk::UIManager> ui = get_ui_manager();
 
@@ -293,6 +307,10 @@ public:
 			"					<menuitem action='video-player/open'/>"
 			"					<menuitem action='video-player/close'/>"
 			"					<separator/>"
+			"					<menu action='menu-audio-track'>"
+			"						<placeholder name='audio-track-placeholder'/>"
+			"					</menu>"
+			"					<separator/>"
 			"					<menuitem action='video-player/play'/>"
 			"					<menuitem action='video-player/pause'/>"
 			"					<menuitem action='video-player/play-pause'/>"
@@ -332,14 +350,15 @@ public:
 			"</ui>";
 
 		ui_id = ui->add_ui_from_string(submenu);
+		ui_id_audio = ui->new_merge_id();
 
 		// Show/Hide video player
 		ui->add_ui(ui_id, "/menubar/menu-view/display-placeholder",
 				"video-player/display", "video-player/display");
 
 		// 
-		player()->signal_state_changed().connect(
-				sigc::mem_fun(*this, &VideoPlayerManagement::on_player_state_changed));
+		player()->signal_message().connect(
+				sigc::mem_fun(*this, &VideoPlayerManagement::on_player_message));
 
 		get_config().signal_changed("video-player").connect(
 				sigc::mem_fun(*this, &VideoPlayerManagement::on_config_video_player_changed));
@@ -354,6 +373,7 @@ public:
 
 		Glib::RefPtr<Gtk::UIManager> ui = get_ui_manager();
 
+		remove_menu_audio_track();
 		ui->remove_ui(ui_id);
 		ui->remove_action_group(action_group);
 	}
@@ -410,18 +430,29 @@ public:
 	 * Check the state of the player. 
 	 * Display the video player if need and update the menu.
 	 */
-	void on_player_state_changed(Player::State state)
+	void on_player_message(Player::Message msg)
 	{
-		// only if the player is enable or disable
-		// don't update if is playing or paused
-		if(state == Player::NONE || state == Player::READY)
+		if(msg == Player::STATE_NONE || msg == Player::STREAM_READY)
 		{
-			update_ui();
+			// only if the player is enable or disable
+			// don't update if is playing or paused
 
-			if(state == Player::READY)
+			if(msg == Player::STATE_NONE)
+				remove_menu_audio_track();
+			else if(msg == Player::STREAM_READY)
+				build_menu_audio_track();
+			update_ui();
+			// If need, ask to display the video player
+			if(msg == Player::STREAM_READY)
 				if(get_config().get_value_bool("video-player", "display") == false)
 					get_config().set_value_bool("video-player", "display", true);
 		}
+		else if(msg == Player::STREAM_AUDIO_CHANGED)
+		{
+			// The player emit the signal audio changed.
+			// We update the current audio if need.
+			update_audio_track_from_player();
+		}
 	}
 
 	/*
@@ -481,6 +512,112 @@ public:
 			}
 		}
 	}
+
+	/*
+	 * We remove the ActionGroup "VideoPlayerManagementAudioTrack"
+	 * and the ui.
+	 */
+	void remove_menu_audio_track()
+	{
+		se_debug(SE_DEBUG_PLUGINS);
+		if(action_group_audio)
+		{
+			get_ui_manager()->remove_ui(ui_id_audio);
+			get_ui_manager()->remove_action_group(action_group_audio);
+			action_group_audio.reset();
+		}
+	}
+
+	/*
+	 * Remove old menu items (tracks) and actions
+	 * and create a new one.
+	 */
+	void build_menu_audio_track()
+	{
+		se_debug(SE_DEBUG_PLUGINS);
+		// We clean the old audio menu
+		remove_menu_audio_track();
+		// Create audio actions
+		action_group_audio = Gtk::ActionGroup::create("VideoPlayerManagementAudioTrack");
+		get_ui_manager()->insert_action_group(action_group_audio);
+
+		Gtk::RadioButtonGroup group;
+		// A default track "Auto"
+		add_audio_track_entry(group, "audio-track-auto", _("Auto"), -1);
+		// Now we build an entry for each audio track
+		gint n_audio = player()->get_n_audio();
+		for(gint i=0; i < n_audio; ++i)
+		{
+			Glib::ustring track = Glib::ustring::compose("audio-track-%1", i);
+			Glib::ustring track_name = Glib::ustring::compose("Track %1", i + 1);
+
+			add_audio_track_entry(group, track, track_name, i);
+		}
+		// active the good track
+		update_audio_track_from_player();
+	}
+
+	/*
+	 * Update the radio item with the current audio track
+	 * from the player.
+	 */
+	void update_audio_track_from_player()
+	{
+		se_debug(SE_DEBUG_PLUGINS);
+
+		if(!action_group_audio)
+			return;
+
+		gint current_audio = player()->get_n_audio();
+		// If it's < -1, we choose the track "Auto"
+		Glib::ustring track_action =  (current_audio < 0) ? "audio-track-auto" : Glib::ustring::compose("audio-track-%1", current_audio);
+
+		Glib::RefPtr<Gtk::ToggleAction> action = Glib::RefPtr<Gtk::ToggleAction>::cast_static(action_group_audio->get_action(track_action));
+		if(action)
+		{
+			if(action->get_active() == false) // Only if need
+				action->set_active(true);
+		}
+	}
+
+	/*
+	 * Create a new track entry (action and menu item).
+	 */
+	void add_audio_track_entry(
+			Gtk::RadioButtonGroup& group, 
+			const Glib::ustring &track_action, 
+			const Glib::ustring &track_label, 
+			gint track_number)
+	{
+		// action
+		Glib::RefPtr<Gtk::RadioAction> action = Gtk::RadioAction::create(group, track_action, track_label);
+		action_group_audio->add( action,
+				sigc::bind(
+					sigc::mem_fun(*this, &VideoPlayerManagement::set_current_audio), track_number, action));
+		// menuitem
+		get_ui_manager()->add_ui(
+				ui_id_audio, 
+				"/menubar/menu-video/video-player-management/menu-audio-track/audio-track-placeholder", 
+				track_action, track_action, Gtk::UI_MANAGER_AUTO, false);
+		// update
+		get_ui_manager()->ensure_update();
+	}
+
+	/*
+	 * The user choose a new track from the track menu, 
+	 * we update the player.
+	 */
+	void set_current_audio(gint track, Glib::RefPtr<Gtk::RadioAction> action)
+	{
+		se_debug(SE_DEBUG_PLUGINS);
+		// Switching a toggle button launch two signal, 
+		// one for the button toggle to unactivated and an other to activated. 
+		// We need to check only for the signal activate.   
+		if(!action->get_active())
+			return;
+		player()->set_current_audio(track);
+	}
+
 protected:
 
 	/*
@@ -790,7 +927,9 @@ protected:
 
 protected:
 	Gtk::UIManager::ui_merge_id ui_id;
+	Gtk::UIManager::ui_merge_id ui_id_audio;
 	Glib::RefPtr<Gtk::ActionGroup> action_group;
+	Glib::RefPtr<Gtk::ActionGroup> action_group_audio;
 };
 
 
