@@ -27,6 +27,11 @@
 #include <waveformmanager.h>
 #include <gui/dialogfilechooser.h>
 
+/*
+ * Declared in waveformgenerator.cc
+ */
+Glib::RefPtr<Waveform> generate_waveform_from_file(const Glib::ustring &uri);
+
 /*
  *
  */
@@ -41,7 +46,7 @@ public:
 	{
 		activate();
 		update_ui();
-		update_ui_from_player(Player::NONE);
+		update_ui_from_player(Player::STATE_NONE);
 	}
 
 	~WaveformManagement()
@@ -131,7 +136,7 @@ public:
 		bool waveform_display_state = get_config().get_value_bool("waveform", "display");
 
 		action_group->add(
-				Gtk::ToggleAction::create("waveform/display", _("_Wavform"), _("Show or hide the waveform in the current window"), waveform_display_state),
+				Gtk::ToggleAction::create("waveform/display", _("_Waveform"), _("Show or hide the waveform in the current window"), waveform_display_state),
 					sigc::mem_fun(*this, &WaveformManagement::on_waveform_display));
 
 		// ui
@@ -183,7 +188,7 @@ public:
 				sigc::mem_fun(*this, &WaveformManagement::on_config_waveform_changed));
 
 		// Player state
-		get_subtitleeditor_window()->get_player()->signal_state_changed().connect(
+		get_subtitleeditor_window()->get_player()->signal_message().connect(
 				sigc::mem_fun(*this, &WaveformManagement::update_ui_from_player));
 	}
 
@@ -227,12 +232,21 @@ public:
 	/*
 	 * Update the ui state from the player state.
 	 */
-	void update_ui_from_player(Player::State state)
+	void update_ui_from_player(Player::Message msg)
 	{
-		bool has_player_file = (state != Player::NONE);
-
-		action_group->get_action("waveform/generate-from-player-file")->set_sensitive(has_player_file);
-		action_group->get_action("waveform/generate-dummy")->set_sensitive(has_player_file);
+		switch(msg)
+		{
+		case Player::STATE_NONE:
+		case Player::STREAM_READY:
+			{
+				Player* player = get_subtitleeditor_window()->get_player();
+				bool has_player_file = (player->get_state() != Player::NONE);
+				action_group->get_action("waveform/generate-from-player-file")->set_sensitive(has_player_file);
+				action_group->get_action("waveform/generate-dummy")->set_sensitive(has_player_file);
+			} break;
+		default:
+			break;
+		}
 	}
 
 protected:
@@ -261,12 +275,17 @@ protected:
 			dialog.hide();
 
 			Glib::ustring uri = dialog.get_uri();
-		
-			WaveformManager* wm = get_waveform_manager();
-			if(wm->open_waveform(uri) == false)
+			Glib::RefPtr<Waveform> wf = Waveform::create_from_file(uri);
+			if(wf)
+				get_waveform_manager()->set_waveform(wf);
+			else
 			{
-				// try to create the Waveform from media
-				wm->generate_waveform(uri);
+				wf = generate_waveform_from_file(uri);
+				if(wf)
+				{
+					get_waveform_manager()->set_waveform(wf);
+					on_save_waveform();
+				}
 			}
 		}
 	}
@@ -278,7 +297,15 @@ protected:
 	{
 		Glib::ustring uri = get_subtitleeditor_window()->get_player()->get_uri();
 		if(uri.empty() == false)
-			get_waveform_manager()->generate_waveform(uri);
+		{
+			//get_waveform_manager()->generate_waveform(uri);
+			Glib::RefPtr<Waveform> wf = generate_waveform_from_file(uri);
+			if(wf)
+			{
+				get_waveform_manager()->set_waveform(wf);
+				on_save_waveform();
+			}
+		}
 	}
 
 	/*
@@ -329,6 +356,8 @@ protected:
 			ui.add_button(Gtk::Stock::OK, Gtk::RESPONSE_OK);
 			ui.set_default_response(Gtk::RESPONSE_OK);
 
+			set_default_filename_from_video(&ui, wf->get_video_uri(), "wf");
+
 			if(ui.run() == Gtk::RESPONSE_OK)
 			{
 				Glib::ustring uri = ui.get_uri();
@@ -338,6 +367,31 @@ protected:
 		}
 	}
 
+	/*
+	 */
+	void set_default_filename_from_video(Gtk::FileChooser *fc, const Glib::ustring &video_uri, const Glib::ustring &ext)
+	{
+		try
+		{
+			Glib::ustring videofn = Glib::filename_from_uri(video_uri);
+			Glib::ustring pathname = Glib::path_get_dirname(videofn);
+			Glib::ustring basename = Glib::path_get_basename(videofn);
+
+			Glib::RefPtr<Glib::Regex> re = Glib::Regex::create("^(.*)(\\.)(.*)$");
+			if(re->match(basename))
+				basename = re->replace(basename, 0, "\\1." + ext, Glib::RegexMatchFlags(0));
+			else
+				basename = Glib::ustring::compose("%1.%2", basename, ext);
+		
+			fc->set_current_folder(pathname); // set_current_folder_uri ?
+			fc->set_current_name(basename);
+		}
+		catch(const Glib::Exception &ex)
+		{
+			std::cerr << "set_default_filename_from_video failed : " << ex.what() << std::endl;
+		}
+	}
+
 	/*
 	 * Update the video player with the new Waveform
 	 * only if it's different.
