@@ -40,23 +40,23 @@ void init_dialog_subtitle_filters(Gtk::FileChooserDialog *dialog)
 	std::list<SubtitleFormatInfo>::const_iterator it;
 	std::list<SubtitleFormatInfo> infos = SubtitleFormatSystem::instance().get_infos();
 
-	Gtk::FileFilter all, supported;
+	Gtk::FileFilter *all=manage(new Gtk::FileFilter), *supported = manage(new Gtk::FileFilter);
 	// all files
 	{
-		all.set_name(_("All files (*.*)"));
-		all.add_pattern("*");
-		dialog->add_filter(all);
+		all->set_name(_("All files (*.*)"));
+		all->add_pattern("*");
+		dialog->add_filter(*all);
 	}
 
 	// all supported formats
 	{
-		supported.set_name(_("All supported formats (*.ass, *.ssa, *.srt, ...)"));
+		supported->set_name(_("All supported formats (*.ass, *.ssa, *.srt, ...)"));
 		for(it = infos.begin(); it != infos.end(); ++it)
 		{
-			supported.add_pattern("*." + (*it).extension);
+			supported->add_pattern("*." + (*it).extension);
 		}
 
-		dialog->add_filter(supported);
+		dialog->add_filter(*supported);
 	}
 
 	// by format
@@ -66,15 +66,15 @@ void init_dialog_subtitle_filters(Gtk::FileChooserDialog *dialog)
 			Glib::ustring name = (*it).name;
 			Glib::ustring ext = (*it).extension;
 	
-			Gtk::FileFilter filter;
-			filter.set_name(name + " (" + ext + ")");
-			filter.add_pattern("*." + ext);
-			dialog->add_filter(filter);
+			Gtk::FileFilter *filter = manage(new Gtk::FileFilter);
+			filter->set_name(name + " (" + ext + ")");
+			filter->add_pattern("*." + ext);
+			dialog->add_filter(*filter);
 		}
 	}
 
 	// select by default
-	dialog->set_filter(supported);
+	dialog->set_filter(*supported);
 }
 
 /*
@@ -103,6 +103,22 @@ DialogFileChooser::~DialogFileChooser()
 	Config::getInstance().set_value_string("dialog-last-folder", m_name, last);
 }
 
+/*
+ * Define the current file filter.
+ * ex: 'Subtitle Editor Project', 'SubRip', 'MicroDVD' ...
+ */
+void DialogFileChooser::set_current_filter(const Glib::ustring &subtitleformat_name)
+{
+	std::list<Gtk::FileFilter*> filters = list_filters();
+	for(std::list<Gtk::FileFilter*>::const_iterator it = filters.begin(); it != filters.end(); ++it)
+	{
+		if((*it)->get_name().find(subtitleformat_name) == Glib::ustring::npos)
+			continue;
+		
+		set_filter(*(*it));
+		return;
+	}
+}
 
 
 /*
@@ -113,12 +129,12 @@ DialogFileChooser::~DialogFileChooser()
 /*
  * Constructor
  */
-DialogOpenDocument::DialogOpenDocument(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
+DialogOpenDocument::DialogOpenDocument(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 :DialogFileChooser(cobject, "dialog-open-document")
 {
-	refGlade->get_widget_derived("combobox-encodings", m_comboEncodings);
-	refGlade->get_widget("label-video", m_labelVideo);
-	refGlade->get_widget_derived("combobox-video", m_comboVideo);
+	builder->get_widget_derived("combobox-encodings", m_comboEncodings);
+	builder->get_widget("label-video", m_labelVideo);
+	builder->get_widget_derived("combobox-video", m_comboVideo);
 
 	signal_current_folder_changed().connect(
 			sigc::mem_fun(*this, &DialogOpenDocument::on_current_folder_changed));
@@ -179,8 +195,8 @@ DialogOpenDocument::auto_ptr DialogOpenDocument::create()
 {
 	auto_ptr ptr( 
 			gtkmm_utility::get_widget_derived<DialogOpenDocument>(
-				SE_DEV_VALUE(PACKAGE_GLADE_DIR, PACKAGE_GLADE_DIR_DEV),
-				"dialog-open-document.glade", 
+				SE_DEV_VALUE(PACKAGE_UI_DIR, PACKAGE_UI_DIR_DEV),
+				"dialog-open-document.ui", 
 				"dialog-open-document") );
 
 	return ptr;
@@ -217,12 +233,12 @@ void DialogOpenDocument::on_selection_changed()
 /*
  * Constructor
  */
-DialogSaveDocument::DialogSaveDocument(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
+DialogSaveDocument::DialogSaveDocument(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 :DialogFileChooser(cobject, "dialog-save-document")
 {
-	refGlade->get_widget_derived("combobox-format", m_comboFormat);
-	refGlade->get_widget_derived("combobox-encodings", m_comboEncodings);
-	refGlade->get_widget_derived("combobox-newline", m_comboNewLine);
+	builder->get_widget_derived("combobox-format", m_comboFormat);
+	builder->get_widget_derived("combobox-encodings", m_comboEncodings);
+	builder->get_widget_derived("combobox-newline", m_comboNewLine);
 
 	init_dialog_subtitle_filters(this);
 
@@ -232,6 +248,9 @@ DialogSaveDocument::DialogSaveDocument(BaseObjectType* cobject, const Glib::RefP
 	add_button(Gtk::Stock::SAVE, Gtk::RESPONSE_OK);
 	
 	set_default_response(Gtk::RESPONSE_OK);
+
+	m_comboFormat->signal_changed().connect(
+			sigc::mem_fun(*this, &DialogSaveDocument::on_combo_format_changed));
 }
 
 /*
@@ -283,6 +302,35 @@ Glib::ustring DialogSaveDocument::get_newline() const
 	return m_comboNewLine->get_value();
 }
 
+/*
+ * Update the extension of the current filename.
+ */
+void DialogSaveDocument::on_combo_format_changed()
+{
+	Glib::ustring filename = get_filename();
+	if(filename.empty())
+		return;
+
+	// Only work with the name of the file
+	Glib::ustring basename = Glib::path_get_basename(filename);
+
+	// Try to get the extension from the format
+	SubtitleFormatInfo sfinfo;
+	if(SubtitleFormatSystem::instance().get_info(get_format(), sfinfo) == false)
+		return;
+	
+	// Test if the name already have an extension then replace the 
+	// previous extension by the new one or simply add the extension to the name.
+	Glib::RefPtr<Glib::Regex> re = Glib::Regex::create("^(.*)(\\.)(.*)$");
+	if(re->match(basename))
+		basename = re->replace(basename, 0, "\\1." + sfinfo.extension, Glib::RegexMatchFlags(0));
+	else
+		basename = basename + "." + sfinfo.extension;
+
+	// Update only the current name
+	set_current_name(basename);
+}
+
 /*
  * Create a instance of the dialog.
  */
@@ -290,8 +338,8 @@ DialogSaveDocument::auto_ptr DialogSaveDocument::create()
 {
 	auto_ptr ptr( 
 			gtkmm_utility::get_widget_derived<DialogSaveDocument>(
-				SE_DEV_VALUE(PACKAGE_GLADE_DIR, PACKAGE_GLADE_DIR_DEV), 
-				"dialog-save-document.glade", 
+				SE_DEV_VALUE(PACKAGE_UI_DIR, PACKAGE_UI_DIR_DEV), 
+				"dialog-save-document.ui", 
 				"dialog-save-document") );
 
 	return ptr;
@@ -305,10 +353,10 @@ DialogSaveDocument::auto_ptr DialogSaveDocument::create()
 /*
  * Constructor
  */
-DialogImportText::DialogImportText(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
+DialogImportText::DialogImportText(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 :DialogFileChooser(cobject, "dialog-import-text")
 {
-	refGlade->get_widget_derived("combobox-encodings", m_comboEncodings);
+	builder->get_widget_derived("combobox-encodings", m_comboEncodings);
 
 	add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
 	add_button(Gtk::Stock::OPEN, Gtk::RESPONSE_OK);
@@ -332,8 +380,8 @@ DialogImportText::auto_ptr DialogImportText::create()
 {
 	auto_ptr ptr( 
 			gtkmm_utility::get_widget_derived<DialogImportText>(
-				SE_DEV_VALUE(PACKAGE_GLADE_DIR, PACKAGE_GLADE_DIR_DEV), 
-				"dialog-import-text.glade", 
+				SE_DEV_VALUE(PACKAGE_UI_DIR, PACKAGE_UI_DIR_DEV), 
+				"dialog-import-text.ui", 
 				"dialog-import-text") );
 
 	return ptr;
@@ -349,11 +397,11 @@ DialogImportText::auto_ptr DialogImportText::create()
 /*
  * Constructor
  */
-DialogExportText::DialogExportText(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
+DialogExportText::DialogExportText(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 :DialogFileChooser(cobject, "dialog-export-text")
 {
-	refGlade->get_widget_derived("combobox-encodings", m_comboEncodings);
-	refGlade->get_widget_derived("combobox-newline", m_comboNewLine);
+	builder->get_widget_derived("combobox-encodings", m_comboEncodings);
+	builder->get_widget_derived("combobox-newline", m_comboNewLine);
 
 	m_comboEncodings->show_auto_detected(false);
 
@@ -387,8 +435,8 @@ DialogExportText::auto_ptr DialogExportText::create()
 {
 	auto_ptr ptr( 
 			gtkmm_utility::get_widget_derived<DialogExportText>(
-				SE_DEV_VALUE(PACKAGE_GLADE_DIR, PACKAGE_GLADE_DIR_DEV),
-				"dialog-export-text.glade", 
+				SE_DEV_VALUE(PACKAGE_UI_DIR, PACKAGE_UI_DIR_DEV),
+				"dialog-export-text.ui", 
 				"dialog-export-text") );
 
 	return ptr;
@@ -531,3 +579,69 @@ DialogOpenWaveform::~DialogOpenWaveform()
 	Config::getInstance().set_value_string("dialog-last-folder", "dialog-open-waveform", floder);
 }
 
+
+/*
+ * Keyframes or Video
+ */
+DialogOpenKeyframe::DialogOpenKeyframe()
+:Gtk::FileChooserDialog(_("Open Keyframe"), Gtk::FILE_CHOOSER_ACTION_OPEN)
+{
+	utility::set_transient_parent(*this);
+
+	// keyframes and video filter
+	Gtk::FileFilter m_filterSupported;
+	m_filterSupported.set_name(_("Keyframe & Media"));
+	m_filterSupported.add_pattern("*.kf");
+	m_filterSupported.add_mime_type("video/*");
+	m_filterSupported.add_pattern("*.avi");
+	m_filterSupported.add_pattern("*.wma");
+	m_filterSupported.add_pattern("*.mkv");
+	m_filterSupported.add_pattern("*.mpg");
+	m_filterSupported.add_pattern("*.mpeg");
+	add_filter(m_filterSupported);
+
+	// keyframe filter
+	Gtk::FileFilter m_filterKeyframe;
+	m_filterKeyframe.set_name(_("Keyframe (*.kf)"));
+	m_filterKeyframe.add_pattern("*.kf");
+	add_filter(m_filterKeyframe);
+
+	// movies filter
+	Gtk::FileFilter m_filterMovie;
+	m_filterMovie.set_name(_("Video"));
+	m_filterMovie.add_pattern("*.avi");
+	m_filterMovie.add_pattern("*.wma");
+	m_filterMovie.add_pattern("*.mkv");
+	m_filterMovie.add_pattern("*.mpg");
+	m_filterMovie.add_pattern("*.mpeg");
+	m_filterMovie.add_mime_type("video/*");
+	add_filter(m_filterMovie);
+
+	// all filter
+	Gtk::FileFilter m_filterAll;
+	m_filterAll.set_name(_("ALL"));
+	m_filterAll.add_pattern("*.*");
+	add_filter(m_filterAll);
+	
+	
+	add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
+	add_button(Gtk::Stock::OK, Gtk::RESPONSE_OK);
+	set_default_response(Gtk::RESPONSE_OK);
+
+
+	Config &cfg = Config::getInstance();
+
+	Glib::ustring floder;
+	if(cfg.get_value_string("dialog-last-folder", "dialog-open-keyframe", floder))
+		set_current_folder_uri(floder);
+}
+
+/*
+ */
+DialogOpenKeyframe::~DialogOpenKeyframe()
+{
+	Glib::ustring floder = get_current_folder_uri();
+
+	Config::getInstance().set_value_string("dialog-last-folder", "dialog-open-keyframe", floder);
+}
+
