@@ -26,7 +26,7 @@
 #include "dialogutility.h"
 
 #include <gtkmm.h>
-#include <libglademm.h>
+#include <gtkmm/builder.h>
 #include <memory>
 
 /*
@@ -55,6 +55,12 @@ public:
 	 */
 	virtual ~DialogFileChooser();
 
+	/*
+	 * Define the current file filter.
+	 * ex: 'Subtitle Editor Project', 'SubRip', 'MicroDVD' ...
+	 */
+	void set_current_filter(const Glib::ustring &subtitleformat_name);
+
 protected:
 	Glib::ustring m_name;
 };
@@ -75,7 +81,7 @@ public:
 	/*
 	 * Constructor
 	 */
-	DialogOpenDocument(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+	DialogOpenDocument(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
 
 	/*
 	 * Returns the encoding value.
@@ -133,7 +139,7 @@ public:
 	/*
 	 * Constructor
 	 */
-	DialogSaveDocument(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+	DialogSaveDocument(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
 
 	/*
 	 * Sets the current format value.
@@ -166,6 +172,11 @@ public:
 	 */
 	Glib::ustring get_newline() const;
 
+	/*
+	 * Update the extension of the current filename.
+	 */
+	void on_combo_format_changed();
+
 	/*
 	 * Create a instance of the dialog.
 	 */
@@ -193,7 +204,7 @@ public:
 	/*
 	 * Constructor
 	 */
-	DialogImportText(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+	DialogImportText(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
 
 	/*
 	 * Returns the encoding value.
@@ -226,7 +237,7 @@ public:
 	/*
 	 * Constructor
 	 */
-	DialogExportText(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+	DialogExportText(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
 
 	/*
 	 * Returns the encoding value. or empty string (Auto Detected).
@@ -271,5 +282,15 @@ public:
 	~DialogOpenWaveform();
 };
 
+/*
+ * Keyframe or Video
+ */
+class DialogOpenKeyframe : public Gtk::FileChooserDialog
+{
+public:
+	DialogOpenKeyframe();
+	~DialogOpenKeyframe();
+};
+
 #endif//_DialogFileChooser_h
 
