@@ -7,7 +7,7 @@
  *	http://home.gna.org/subtitleeditor/
  *	https://gna.org/projects/subtitleeditor/
  *
- *	Copyright @ 2005-2009, kitone
+ *	Copyright @ 2005-2010, kitone
  *
  *	This program is free software; you can redistribute it and/or modify
  *	it under the terms of the GNU General Public License as published by
@@ -25,26 +25,28 @@
  
 
 #include <gtkmm.h>
-#include <libglademm/xml.h>
+#include <gtkmm/builder.h>
 #include "documentsystem.h"
+#include <gui/comboboxframerate.h>
 
 /*
- *
- *
  */
 class DialogActionMultiDoc : public Gtk::Dialog
 {
 public:
-	DialogActionMultiDoc(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
 
 	/*
-	 *	applique l'action à tous les documents
+	 * Constructor
+	 */
+	DialogActionMultiDoc(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
+
+	/*
+	 * Return true if the user choose to apply the action on all documents.
 	 */
 	bool apply_to_all_documents();
 
 	/*
-	 *	retourne la list des documents à modifier
-	 *	selon qu'on utilise "current document" ou "All documents"
+	 * Return a list of documents that the user wants to change.
 	 */
 	DocumentList get_documents_to_apply();
 
@@ -55,17 +57,44 @@ protected:
 
 
 /*
- *
  */
 class ErrorDialog : public Gtk::MessageDialog
 {
 public:
 
 	/*
-	 *
 	 */
 	ErrorDialog(const Glib::ustring &primary, const Glib::ustring &secondary=Glib::ustring());
 };
 
+/*
+ */
+class FramerateChooserDialog : public Gtk::Dialog
+{
+public:
+
+	enum Action
+	{
+		IMPORT,
+		EXPORT
+	};
+
+	/*
+	 */
+	FramerateChooserDialog(Action action = IMPORT);
+
+	/*
+	 * Launch the dialog and return the framerate value.
+	 */
+	FRAMERATE execute();
+
+	/*
+	 */
+	void set_default_framerate(FRAMERATE framerate);
+
+protected:
+	Gtk::ComboBox* m_comboFramerate;
+};
+
 #endif//_DialogUtility_h
 
